#ifndef BUFFER_H
#define	BUFFER_H

/*****************************************************************************
 * Buffer.h - Generic Circular Buffer Handler for Character Data
 ****************************************************************************/

/*****************************************************************************
 * Definitions
 ****************************************************************************/

#define BUFSIZ		32      // Size of buffer, in characters

struct Buffer {
    char Buf[BUFSIZ];
    unsigned char PutPtr;
    unsigned char GetPtr;
    unsigned char Cnt;
};


/*****************************************************************************
 * BufInit - Initializer Buffer
 ****************************************************************************/
void BufInit(volatile struct Buffer *buf) {
    int i;

    buf->PutPtr = 0;
    buf->GetPtr = 0;
    buf->Cnt = 0;
    for (i=0; i<BUFSIZ; i++)
        buf->Buf[i] = 0xff;
}


/*****************************************************************************
 * BufPut - Add character to Buffer
 * Returns 0 if ok, non-zero if buffer
 * is full.
 ****************************************************************************/
char BufPut(volatile struct Buffer *buf, char c) {
    char ret = 1;

    if (buf->Cnt < BUFSIZ - 1) {
        buf->Buf[buf->PutPtr] = c;
        if (++buf->PutPtr == BUFSIZ)
            buf->PutPtr = 0;
        buf->Cnt++;
        ret = 0;
    }
    return ret;
}


/*****************************************************************************
 * BufGet - Get next character from Buffer
 * Returns character if available,
 * zero if buffer is empty.
 ****************************************************************************/
char BufGet(volatile struct Buffer *buf) {
    char ret = 0;

    if (buf->Cnt > 0) {
        buf->Cnt--;
        ret = buf->Buf[buf->GetPtr];
        if (++buf->GetPtr == BUFSIZ)
            buf->GetPtr = 0;
    }
    return ret;
}

#endif

