#ifndef DEBOUNCE_H
#define DEBOUNCE_H

/*****************************************************************************
 * Debounce.h - Software Debounce for 8-bit Data
 ****************************************************************************/

/*****************************************************************************
 * Definitions
 ****************************************************************************/

#define DEBOUNCE_CNT    10  // Debounce Count, in mSec

struct DebounceData {
    char Val;
    char NewVal;
    char Cnt;
};


/*****************************************************************************
 * DebounceInit - Initializes/Re-initializes a DebounceData structure
 ****************************************************************************/
void DebounceInit(struct DebounceData *db, char val)
{
    db->Val = val;
    db->NewVal = val;
    db->Cnt = 0;
}


/*****************************************************************************
 * DebounceUpdate - Called every millisecond by timer interrupt
 ****************************************************************************/
void DebounceUpdate(struct DebounceData *db, char newval)
{
    if (((db->Cnt == 0) && (newval != db->Val)) ||
        ((db->Cnt > 0) && (newval != db->NewVal))) {
        // Input has changed, so start debounce
        db->NewVal = newval;
        db->Cnt = DEBOUNCE_CNT;
    } else if (db->Cnt == 1) {
        // Debounce is complete, so commit new value
        db->Val = db->NewVal;
        db->Cnt = 0;
    } else if (db->Cnt > 0) {
        // Value is stable, so just continue debounce
        db->Cnt--;
    }
}

#endif