#ifndef TIMER_H
#define TIMER_H

/*****************************************************************************
 * Timer.h - 1mSec Interrupt Timer
 ****************************************************************************/

#include "timers.h"


/*****************************************************************************
 * Private Data
 ****************************************************************************/

unsigned long TimerTicks;
unsigned int mSec;
unsigned char Sec;
unsigned char Min;
unsigned char Hour;
unsigned int BlinkTimer;


/*****************************************************************************
 * TimerOpen() - Initializer Timer
 ****************************************************************************/
void TimerOpen(void) {
    // Setup TMR2 to generate 1mSec interrupts
    TimerTicks = 0;
    mSec = 0;
    Sec = 0;
    Min = 0;
    Hour = 0;
    BlinkTimer = 0;

    /*   Setup for 1mSec interrupts: 
     *      FOSC=24MHz 
     *      TMR2: Pre-scale=4, PostScale=10, Count=150
     */
    T2CONbits.T2CKPS = 1;
    T2CONbits.TOUTPS = 9;
    TMR2 = 0;
    PR2 = 150;
    T2CONbits.TMR2ON = 1;
    PIE1bits.TMR2IE = 1;
}


/*****************************************************************************
 * TimerClose() - Turn Off Timer
 ****************************************************************************/
void TimerClose(void) {
    CloseTimer2();
}


/*****************************************************************************
 * TimerHandler - 1mSec Timer Interrupt Handler
 ****************************************************************************/
void TimerHandler(void) {

    // Count this tick
    TimerTicks++;

    // Update RTC
    if (++mSec == 1000) {
        mSec = 0;
#ifdef TIMERBLINK
        EStopLEDBit = CurrentEStop ^ 1;
        BlinkTimer = BLINKTIME;
#else
        if (CurrentEStop) {
            EStopLEDBit = CurrentEStop ^ 1;
            BlinkTimer = 500;
        }
#endif
        if (++Sec == 60) {
            Sec = 0;
            if (++Min == 60) {
                Min = 0;
                if (++Hour == 24) {
                    Hour = 0;
                }
            }
        }
    }

    if (BlinkTimer > 0) {
        if (--BlinkTimer == 0)
            EStopLEDBit = CurrentEStop;
    }

    // Clear the interrupt
    PIR1bits.TMR2IF = 0;
}

#endif